from netforce.model import Model, fields, get_model
from netforce.utils import get_data_path
import time
from netforce.access import get_active_user
from netforce.access import get_active_company

class Hdcase(Model):
    _name="clinic.hd.case"
    _string="HD Case Treatment"
    _audit_log=True
    _name_field="number"
    _multi_company=True
    _fields={
        "number": fields.Char("Number",required=True,search=True),
        "patient_id": fields.Many2One("clinic.patient","Patients",required=True,search=True),
        "doctor_id": fields.Many2One("clinic.doctor","Doctor",search=True),
        "nurse_id": fields.Many2One("clinic.nurse","Nurse",search=True),
        "date_start": fields.DateTime("Date start",required=True,search=True),
        "date_stop": fields.DateTime("Date stop",required=True,search=True),
        "department": fields.Char("Department",required=False,search=True),
        "wh_start": fields.Float("Wt.Kg start",required=True,search=True),
        "wh_stop": fields.Float("Wt.Kg stop",required=True,search=True),
        "bp_start": fields.Integer("BP mmHG start",required=True,search=True),
        "per_bp_start": fields.Integer("/Per start",required=True,search=True),
        "bp_stop": fields.Integer("BP mmHG stop",required=True,search=True),
        "per_bp_stop": fields.Integer("/Per stop",required=True,search=True),
        "hct": fields.Integer("HCT %",required=True,search=True),
        "state": fields.Selection([("draft","Draft"),("pending","Pending"),("confirmed","Confirmed"),("canceled","Canceled")],"Status",required=True),
        "lines": fields.One2Many("clinic.hd.case.line","hd_case_id","Details"),
        "lines_detail": fields.One2Many("clinic.hd.case.line.detail","hd_case_id","Detail"),
        "comments": fields.One2Many("message","related_id","Comments"),
        "company_id": fields.Many2One("company","Company"),
    }

    def _get_number(self,context={}):
        while 1:
            num=get_model("sequence").get_number("sale_order")
            if not num:
                return None
            res=self.search([["number","=",num]])
            if not res:
                return num
            get_model("sequence").increment("sale_order")

    def onchange_dialyzer(self,context={}):
        data=context["data"]
        path=context["path"]
        line=get_data_path(data,path,parent=True)
        dialyzer_id=line.get("dialzer_id")
        if not dialyzer_id:
            return {}
        dialyzer=get_model("clinic.dialyzer").browse(dialyzer_id)
        line["detail"]=dialyzer.detail
        line["use_time"]=dialyzer.use_time
        line["max_use_time"]=dialyzer.max_use_time
        line["member_type"]=dialyzer.member_type
        line["dialyzer_type"]=dialyzer.dialyzer_type
        line["bid_flow_rate"]=dialyzer.bid_flow_rate
        line["ultrafittration"]=dialyzer.ultrafittration
        line["state"]=dialyzer.state
        return data

    _defaults={
        "state": "draft",
        "date_start": lambda *a: time.strftime("%Y-%m-%d %H:%M:%S"),
        "date_stop": lambda *a: time.strftime("%Y-%m-%d %H:%M:%S"),
        "number": _get_number,
        "company_id": lambda *a: get_active_company(),
    }
    _order="date desc,number desc"



    def void(self,ids,context={}):
        obj=self.browse(ids)[0]
        obj.write({"state":"voided"})


Hdcase.register()
